@@ -2,7 +2,7 @@ import os
 import re
 import ConfigParser
 
-VERSION = "0.7"
+VERSION = "0.7.1"
 
 if os.environ.has_key("PYTHONBREW_ROOT"):
     ROOT = os.environ["PYTHONBREW_ROOT"]
@@ -21,6 +21,7 @@ PATH_LOG = os.path.join(ROOT,"log")
 PATH_SCRIPTS = os.path.join(ROOT,"scripts")
 PATH_SCRIPTS_PYTHONBREW = os.path.join(PATH_SCRIPTS,"pythonbrew")
 PATH_SCRIPTS_PYTHONBREW_COMMANDS = os.path.join(PATH_SCRIPTS_PYTHONBREW,"commands")
+PATH_SCRIPTS_PYTHONBREW_INSTALLER = os.path.join(PATH_SCRIPTS_PYTHONBREW,"installer")
 PATH_PATCHES = os.path.join(ROOT,"patches")
 PATH_PATCHES_MACOSX = os.path.join(PATH_PATCHES,"macosx")
 PATH_PATCHES_MACOSX_PYTHON25 = os.path.join(PATH_PATCHES_MACOSX,"python25")
